==> swiftgui-0.4.3.tar.gz: swiftgui-0.4.3/src/SwiftGUI/Colors.py <==
import enum

def rgb(r:int,g:int,b:int) -> str:
    """
    Generate a color-string from r,g,b-values
    :param r: red
    :param g: green
    :param b: blue
    :return: Finished color-string
    """

    return f"#{r:#05x}{g:#05x}{b:#05x}".replace("0x","")

class Color:
    # gray0-gray99 weren't included, except for gray0, gray20, gray40,...
    AntiqueWhite1 = "AntiqueWhite1"
    AntiqueWhite2 = "AntiqueWhite2"
    AntiqueWhite3 = "AntiqueWhite3"
    AntiqueWhite4 = "AntiqueWhite4"
    CadetBlue1 = "CadetBlue1"
    CadetBlue2 = "CadetBlue2"
    CadetBlue3 = "CadetBlue3"
    CadetBlue4 = "CadetBlue4"
    DarkGoldenrod1 = "DarkGoldenrod1"
    DarkGoldenrod2 = "DarkGoldenrod2"
    DarkGoldenrod3 = "DarkGoldenrod3"
    DarkGoldenrod4 = "DarkGoldenrod4"
    DarkOliveGreen1 = "DarkOliveGreen1"
    DarkOliveGreen2 = "DarkOliveGreen2"
    DarkOliveGreen3 = "DarkOliveGreen3"
    DarkOliveGreen4 = "DarkOliveGreen4"
    DarkOrange1 = "DarkOrange1"
    DarkOrange2 = "DarkOrange2"
    DarkOrange3 = "DarkOrange3"
    DarkOrange4 = "DarkOrange4"
    DarkOrchid1 = "DarkOrchid1"
    DarkOrchid2 = "DarkOrchid2"
    DarkOrchid3 = "DarkOrchid3"
    DarkOrchid4 = "DarkOrchid4"
    DarkSeaGreen1 = "DarkSeaGreen1"
    DarkSeaGreen2 = "DarkSeaGreen2"
    DarkSeaGreen3 = "DarkSeaGreen3"
    DarkSeaGreen4 = "DarkSeaGreen4"
    DarkSlateGray1 = "DarkSlateGray1"
    DarkSlateGray2 = "DarkSlateGray2"
    DarkSlateGray3 = "DarkSlateGray3"
    DarkSlateGray4 = "DarkSlateGray4"
    DeepPink2 = "DeepPink2"
    DeepPink3 = "DeepPink3"
    DeepPink4 = "DeepPink4"
    DeepSkyBlue2 = "DeepSkyBlue2"
    DeepSkyBlue3 = "DeepSkyBlue3"
    DeepSkyBlue4 = "DeepSkyBlue4"
    DodgerBlue2 = "DodgerBlue2"
    DodgerBlue3 = "DodgerBlue3"
    DodgerBlue4 = "DodgerBlue4"
    HotPink1 = "HotPink1"
    HotPink2 = "HotPink2"
    HotPink3 = "HotPink3"
    HotPink4 = "HotPink4"
    IndianRed1 = "IndianRed1"
    IndianRed2 = "IndianRed2"
    IndianRed3 = "IndianRed3"
    IndianRed4 = "IndianRed4"
    LavenderBlush2 = "LavenderBlush2"
    LavenderBlush3 = "LavenderBlush3"
    LavenderBlush4 = "LavenderBlush4"
    LemonChiffon2 = "LemonChiffon2"
    LemonChiffon3 = "LemonChiffon3"
    LemonChiffon4 = "LemonChiffon4"
    LightBlue1 = "LightBlue1"
    LightBlue2 = "LightBlue2"
    LightBlue3 = "LightBlue3"
    LightBlue4 = "LightBlue4"
    LightCyan2 = "LightCyan2"
    LightCyan3 = "LightCyan3"
    LightCyan4 = "LightCyan4"
    LightGoldenrod1 = "LightGoldenrod1"
    LightGoldenrod2 = "LightGoldenrod2"
    LightGoldenrod3 = "LightGoldenrod3"
    LightGoldenrod4 = "LightGoldenrod4"
    LightPink1 = "LightPink1"
    LightPink2 = "LightPink2"
    LightPink3 = "LightPink3"
    LightPink4 = "LightPink4"
    LightSalmon2 = "LightSalmon2"
    LightSalmon3 = "LightSalmon3"
    LightSalmon4 = "LightSalmon4"
    LightSkyBlue1 = "LightSkyBlue1"
    LightSkyBlue2 = "LightSkyBlue2"
    LightSkyBlue3 = "LightSkyBlue3"
    LightSkyBlue4 = "LightSkyBlue4"
    LightSteelBlue1 = "LightSteelBlue1"
    LightSteelBlue2 = "LightSteelBlue2"
    LightSteelBlue3 = "LightSteelBlue3"
    LightSteelBlue4 = "LightSteelBlue4"
    LightYellow2 = "LightYellow2"
    LightYellow3 = "LightYellow3"
    LightYellow4 = "LightYellow4"
    MediumOrchid1 = "MediumOrchid1"
    MediumOrchid2 = "MediumOrchid2"
    MediumOrchid3 = "MediumOrchid3"
    MediumOrchid4 = "MediumOrchid4"
    MediumPurple1 = "MediumPurple1"
    MediumPurple2 = "MediumPurple2"
    MediumPurple3 = "MediumPurple3"
    MediumPurple4 = "MediumPurple4"
    MistyRose2 = "MistyRose2"
    MistyRose3 = "MistyRose3"
    MistyRose4 = "MistyRose4"
    NavajoWhite2 = "NavajoWhite2"
    NavajoWhite3 = "NavajoWhite3"
    NavajoWhite4 = "NavajoWhite4"
    OliveDrab1 = "OliveDrab1"
    OliveDrab2 = "OliveDrab2"
    OliveDrab4 = "OliveDrab4"
    OrangeRed2 = "OrangeRed2"
    OrangeRed3 = "OrangeRed3"
    OrangeRed4 = "OrangeRed4"
    PaleGreen1 = "PaleGreen1"
    PaleGreen2 = "PaleGreen2"
    PaleGreen3 = "PaleGreen3"
    PaleGreen4 = "PaleGreen4"
    PaleTurquoise1 = "PaleTurquoise1"
    PaleTurquoise2 = "PaleTurquoise2"
    PaleTurquoise3 = "PaleTurquoise3"
    PaleTurquoise4 = "PaleTurquoise4"
    PaleVioletRed1 = "PaleVioletRed1"
    PaleVioletRed2 = "PaleVioletRed2"
    PaleVioletRed3 = "PaleVioletRed3"
    PaleVioletRed4 = "PaleVioletRed4"
    PeachPuff2 = "PeachPuff2"
    PeachPuff3 = "PeachPuff3"
    PeachPuff4 = "PeachPuff4"
    RosyBrown1 = "RosyBrown1"
    RosyBrown2 = "RosyBrown2"
    RosyBrown3 = "RosyBrown3"
    RosyBrown4 = "RosyBrown4"
    RoyalBlue1 = "RoyalBlue1"
    RoyalBlue2 = "RoyalBlue2"
    RoyalBlue3 = "RoyalBlue3"
    RoyalBlue4 = "RoyalBlue4"
    SeaGreen1 = "SeaGreen1"
    SeaGreen2 = "SeaGreen2"
    SeaGreen3 = "SeaGreen3"
    SkyBlue1 = "SkyBlue1"
    SkyBlue2 = "SkyBlue2"
    SkyBlue3 = "SkyBlue3"
    SkyBlue4 = "SkyBlue4"
    SlateBlue1 = "SlateBlue1"
    SlateBlue2 = "SlateBlue2"
    SlateBlue3 = "SlateBlue3"
    SlateBlue4 = "SlateBlue4"
    SlateGray1 = "SlateGray1"
    SlateGray2 = "SlateGray2"
    SlateGray3 = "SlateGray3"
    SlateGray4 = "SlateGray4"
    SpringGreen2 = "SpringGreen2"
    SpringGreen3 = "SpringGreen3"
    SpringGreen4 = "SpringGreen4"
    SteelBlue1 = "SteelBlue1"
    SteelBlue2 = "SteelBlue2"
    SteelBlue3 = "SteelBlue3"
    SteelBlue4 = "SteelBlue4"
    VioletRed1 = "VioletRed1"
    VioletRed2 = "VioletRed2"
    VioletRed3 = "VioletRed3"
    VioletRed4 = "VioletRed4"
    alice_blue = "aliceblue"
    antique_white = "antiquewhite"
    aquamarine = "aquamarine"
    aquamarine2 = "aquamarine2"
    aquamarine4 = "aquamarine4"
    azure = "azure"
    azure2 = "azure2"
    azure3 = "azure3"
    azure4 = "azure4"
    bisque = "bisque"
    bisque2 = "bisque2"
    bisque3 = "bisque3"
    bisque4 = "bisque4"
    blanched_almond = "blanchedalmond"
    blue = "blue"
    blue2 = "blue2"
    blue4 = "blue4"
    blue_violet = "blueviolet"
    brown1 = "brown1"
    brown2 = "brown2"
    brown3 = "brown3"
    brown4 = "brown4"
    burlywood1 = "burlywood1"
    burlywood2 = "burlywood2"
    burlywood3 = "burlywood3"
    burlywood4 = "burlywood4"
    cadet_blue = "cadetblue"
    chartreuse2 = "chartreuse2"
    chartreuse3 = "chartreuse3"
    chartreuse4 = "chartreuse4"
    chocolate1 = "chocolate1"
    chocolate2 = "chocolate2"
    chocolate3 = "chocolate3"
    coral = "coral"
    coral1 = "coral1"
    coral2 = "coral2"
    coral3 = "coral3"
    coral4 = "coral4"
    cornflower_blue = "cornflowerblue"
    cornsilk2 = "cornsilk2"
    cornsilk3 = "cornsilk3"
    cornsilk4 = "cornsilk4"
    cyan = "cyan"
    cyan2 = "cyan2"
    cyan3 = "cyan3"
    cyan4 = "cyan4"
    dark_goldenrod = "darkgoldenrod"
    dark_green = "darkgreen"
    dark_khaki = "darkkhaki"
    dark_olive_green = "darkolivegreen"
    dark_orange = "darkorange"
    dark_orchid = "darkorchid"
    dark_salmon = "darksalmon"
    dark_sea_green = "darkseagreen"
    dark_slate_blue = "darkslateblue"
    dark_slate_gray = "darkslategray"
    dark_turquoise = "darkturquoise"
    dark_violet = "darkviolet"
    deep_pink = "deeppink"
    deep_sky_blue = "deepskyblue"
    dim_gray = "dimgray"
    dodger_blue = "dodgerblue"
    firebrick1 = "firebrick1"
    firebrick2 = "firebrick2"
    firebrick3 = "firebrick3"
    firebrick4 = "firebrick4"
    floral_white = "floralwhite"
    forest_green = "forestgreen"
    gainsboro = "gainsboro"
    ghost_white = "ghostwhite"
    gold = "gold"
    gold2 = "gold2"
    gold3 = "gold3"
    gold4 = "gold4"
    goldenrod = "goldenrod"
    goldenrod1 = "goldenrod1"
    goldenrod2 = "goldenrod2"
    goldenrod3 = "goldenrod3"
    goldenrod4 = "goldenrod4"
    gray = "gray"
    gray0 = "gray0"
    gray100 = "gray100"
    gray20 = "gray20"
    gray40 = "gray40"
    gray60 = "gray60"
    gray80 = "gray80"
    green2 = "green2"
    green3 = "green3"
    green4 = "green4"
    green_yellow = "greenyellow"
    honeydew2 = "honeydew2"
    honeydew3 = "honeydew3"
    honeydew4 = "honeydew4"
    hot_pink = "hotpink"
    indian_red = "indianred"
    ivory2 = "ivory2"
    ivory3 = "ivory3"
    ivory4 = "ivory4"
    khaki = "khaki"
    khaki1 = "khaki1"
    khaki2 = "khaki2"
    khaki3 = "khaki3"
    khaki4 = "khaki4"
    lavender = "lavender"
    lavender_blush = "lavenderblush"
    lawn_green = "lawngreen"
    lemon_chiffon = "lemonchiffon"
    light_blue = "lightblue"
    light_coral = "lightcoral"
    light_cyan = "lightcyan"
    light_goldenrod = "lightgoldenrod"
    light_goldenrod_yellow = "lightgoldenrodyellow"
    light_grey = "lightgrey"
    light_pink = "lightpink"
    light_salmon = "lightsalmon"
    light_sea_green = "lightseagreen"
    light_sky_blue = "lightskyblue"
    light_slate_blue = "lightslateblue"
    light_slate_gray = "lightslategray"
    light_steel_blue = "lightsteelblue"
    light_yellow = "lightyellow"
    lime_green = "limegreen"
    linen = "linen"
    magenta2 = "magenta2"
    magenta3 = "magenta3"
    magenta4 = "magenta4"
    maroon = "maroon"
    maroon1 = "maroon1"
    maroon2 = "maroon2"
    maroon3 = "maroon3"
    maroon4 = "maroon4"
    medium_aquamarine = "mediumaquamarine"
    medium_blue = "mediumblue"
    medium_orchid = "mediumorchid"
    medium_purple = "mediumpurple"
    medium_sea_green = "mediumseagreen"
    medium_slate_blue = "mediumslateblue"
    medium_spring_green = "mediumspringgreen"
    medium_turquoise = "mediumturquoise"
    medium_violet_red = "mediumvioletred"
    midnight_blue = "midnightblue"
    mint_cream = "mintcream"
    misty_rose = "mistyrose"
    navajo_white = "navajowhite"
    navy = "navy"
    old_lace = "oldlace"
    olive_drab = "olivedrab"
    orange = "orange"
    orange2 = "orange2"
    orange3 = "orange3"
    orange4 = "orange4"
    orange_red = "orangered"
    orchid1 = "orchid1"
    orchid2 = "orchid2"
    orchid3 = "orchid3"
    orchid4 = "orchid4"
    pale_goldenrod = "palegoldenrod"
    pale_green = "palegreen"
    pale_turquoise = "paleturquoise"
    pale_violet_red = "palevioletred"
    papaya_whip = "papayawhip"
    peach_puff = "peachpuff"
    pink = "pink"
    pink1 = "pink1"
    pink2 = "pink2"
    pink3 = "pink3"
    pink4 = "pink4"
    plum1 = "plum1"
    plum2 = "plum2"
    plum3 = "plum3"
    plum4 = "plum4"
    powder_blue = "powderblue"
    purple = "purple"
    purple1 = "purple1"
    purple2 = "purple2"
    purple3 = "purple3"
    purple4 = "purple4"
    red = "red"
    red2 = "red2"
    red3 = "red3"
    red4 = "red4"
    rosy_brown = "rosybrown"
    royal_blue = "royalblue"
    saddle_brown = "saddlebrown"
    salmon = "salmon"
    salmon1 = "salmon1"
    salmon2 = "salmon2"
    salmon3 = "salmon3"
    salmon4 = "salmon4"
    sandy_brown = "sandybrown"
    sea_green = "seagreen"
    seashell2 = "seashell2"
    seashell3 = "seashell3"
    seashell4 = "seashell4"
    sienna1 = "sienna1"
    sienna2 = "sienna2"
    sienna3 = "sienna3"
    sienna4 = "sienna4"
    sky_blue = "skyblue"
    slate_blue = "slateblue"
    slate_gray = "slategray"
    snow = "snow"
    snow2 = "snow2"
    snow3 = "snow3"
    snow4 = "snow4"
    spring_green = "springgreen"
    steel_blue = "steelblue"
    tan1 = "tan1"
    tan2 = "tan2"
    tan4 = "tan4"
    thistle = "thistle"
    thistle1 = "thistle1"
    thistle2 = "thistle2"
    thistle3 = "thistle3"
    thistle4 = "thistle4"
    tomato = "tomato"
    tomato2 = "tomato2"
    tomato3 = "tomato3"
    tomato4 = "tomato4"
    turquoise = "turquoise"
    turquoise1 = "turquoise1"
    turquoise2 = "turquoise2"
    turquoise3 = "turquoise3"
    turquoise4 = "turquoise4"
    violet_red = "violetred"
    wheat1 = "wheat1"
    wheat2 = "wheat2"
    wheat3 = "wheat3"
    wheat4 = "wheat4"
    white_smoke = "whitesmoke"
    yellow = "yellow"
    yellow2 = "yellow2"
    yellow3 = "yellow3"
    yellow4 = "yellow4"
    yellow_green = "yellowgreen"

==> swiftgui-0.10.0.tar.gz: swiftgui-0.10.0/src/SwiftGUI/Colors.py <==

def rgb(r:int,g:int,b:int) -> str:
    """
    Generate a color-string from r,g,b-values
    :param r: red
    :param g: green
    :param b: blue
    :return: Finished color-string
    """
    r = min(r, 255)
    g = min(g, 255)
    b = min(b, 255)

    return f"#{r:#04x}{g:#04x}{b:#04x}".replace("0x","").upper()

class Color:
    # gray0-gray99 weren't included, except for gray0, gray20, gray40,...
    AntiqueWhite1 = "AntiqueWhite1"
    AntiqueWhite2 = "AntiqueWhite2"
    AntiqueWhite3 = "AntiqueWhite3"
    AntiqueWhite4 = "AntiqueWhite4"
    CadetBlue1 = "CadetBlue1"
    CadetBlue2 = "CadetBlue2"
    CadetBlue3 = "CadetBlue3"
    CadetBlue4 = "CadetBlue4"
    DarkGoldenrod1 = "DarkGoldenrod1"
    DarkGoldenrod2 = "DarkGoldenrod2"
    DarkGoldenrod3 = "DarkGoldenrod3"
    DarkGoldenrod4 = "DarkGoldenrod4"
    DarkOliveGreen1 = "DarkOliveGreen1"
    DarkOliveGreen2 = "DarkOliveGreen2"
    DarkOliveGreen3 = "DarkOliveGreen3"
    DarkOliveGreen4 = "DarkOliveGreen4"
    DarkOrange1 = "DarkOrange1"
    DarkOrange2 = "DarkOrange2"
    DarkOrange3 = "DarkOrange3"
    DarkOrange4 = "DarkOrange4"
    DarkOrchid1 = "DarkOrchid1"
    DarkOrchid2 = "DarkOrchid2"
    DarkOrchid3 = "DarkOrchid3"
    DarkOrchid4 = "DarkOrchid4"
    DarkSeaGreen1 = "DarkSeaGreen1"
    DarkSeaGreen2 = "DarkSeaGreen2"
    DarkSeaGreen3 = "DarkSeaGreen3"
    DarkSeaGreen4 = "DarkSeaGreen4"
    DarkSlateGray1 = "DarkSlateGray1"
    DarkSlateGray2 = "DarkSlateGray2"
    DarkSlateGray3 = "DarkSlateGray3"
    DarkSlateGray4 = "DarkSlateGray4"
    DeepPink2 = "DeepPink2"
    DeepPink3 = "DeepPink3"
    DeepPink4 = "DeepPink4"
    DeepSkyBlue2 = "DeepSkyBlue2"
    DeepSkyBlue3 = "DeepSkyBlue3"
    DeepSkyBlue4 = "DeepSkyBlue4"
    DodgerBlue2 = "DodgerBlue2"
    DodgerBlue3 = "DodgerBlue3"
    DodgerBlue4 = "DodgerBlue4"
    HotPink1 = "HotPink1"
    HotPink2 = "HotPink2"
    HotPink3 = "HotPink3"
    HotPink4 = "HotPink4"
    IndianRed1 = "IndianRed1"
    IndianRed2 = "IndianRed2"
    IndianRed3 = "IndianRed3"
    IndianRed4 = "IndianRed4"
    LavenderBlush2 = "LavenderBlush2"
    LavenderBlush3 = "LavenderBlush3"
    LavenderBlush4 = "LavenderBlush4"
    LemonChiffon2 = "LemonChiffon2"
    LemonChiffon3 = "LemonChiffon3"
    LemonChiffon4 = "LemonChiffon4"
    LightBlue1 = "LightBlue1"
    LightBlue2 = "LightBlue2"
    LightBlue3 = "LightBlue3"
    LightBlue4 = "LightBlue4"
    LightCyan2 = "LightCyan2"
    LightCyan3 = "LightCyan3"
    LightCyan4 = "LightCyan4"
    LightGoldenrod1 = "LightGoldenrod1"
    LightGoldenrod2 = "LightGoldenrod2"
    LightGoldenrod3 = "LightGoldenrod3"
    LightGoldenrod4 = "LightGoldenrod4"
    LightPink1 = "LightPink1"
    LightPink2 = "LightPink2"
    LightPink3 = "LightPink3"
    LightPink4 = "LightPink4"
    LightSalmon2 = "LightSalmon2"
    LightSalmon3 = "LightSalmon3"
    LightSalmon4 = "LightSalmon4"
    LightSkyBlue1 = "LightSkyBlue1"
    LightSkyBlue2 = "LightSkyBlue2"
    LightSkyBlue3 = "LightSkyBlue3"
    LightSkyBlue4 = "LightSkyBlue4"
    LightSteelBlue1 = "LightSteelBlue1"
    LightSteelBlue2 = "LightSteelBlue2"
    LightSteelBlue3 = "LightSteelBlue3"
    LightSteelBlue4 = "LightSteelBlue4"
    LightYellow2 = "LightYellow2"
    LightYellow3 = "LightYellow3"
    LightYellow4 = "LightYellow4"
    MediumOrchid1 = "MediumOrchid1"
    MediumOrchid2 = "MediumOrchid2"
    MediumOrchid3 = "MediumOrchid3"
    MediumOrchid4 = "MediumOrchid4"
    MediumPurple1 = "MediumPurple1"
    MediumPurple2 = "MediumPurple2"
    MediumPurple3 = "MediumPurple3"
    MediumPurple4 = "MediumPurple4"
    MistyRose2 = "MistyRose2"
    MistyRose3 = "MistyRose3"
    MistyRose4 = "MistyRose4"
    NavajoWhite2 = "NavajoWhite2"
    NavajoWhite3 = "NavajoWhite3"
    NavajoWhite4 = "NavajoWhite4"
    OliveDrab1 = "OliveDrab1"
    OliveDrab2 = "OliveDrab2"
    OliveDrab4 = "OliveDrab4"
    OrangeRed2 = "OrangeRed2"
    OrangeRed3 = "OrangeRed3"
    OrangeRed4 = "OrangeRed4"
    PaleGreen1 = "PaleGreen1"
    PaleGreen2 = "PaleGreen2"
    PaleGreen3 = "PaleGreen3"
    PaleGreen4 = "PaleGreen4"
    PaleTurquoise1 = "PaleTurquoise1"
    PaleTurquoise2 = "PaleTurquoise2"
    PaleTurquoise3 = "PaleTurquoise3"
    PaleTurquoise4 = "PaleTurquoise4"
    PaleVioletRed1 = "PaleVioletRed1"
    PaleVioletRed2 = "PaleVioletRed2"
    PaleVioletRed3 = "PaleVioletRed3"
    PaleVioletRed4 = "PaleVioletRed4"
    PeachPuff2 = "PeachPuff2"
    PeachPuff3 = "PeachPuff3"
    PeachPuff4 = "PeachPuff4"
    RosyBrown1 = "RosyBrown1"
    RosyBrown2 = "RosyBrown2"
    RosyBrown3 = "RosyBrown3"
    RosyBrown4 = "RosyBrown4"
    RoyalBlue1 = "RoyalBlue1"
    RoyalBlue2 = "RoyalBlue2"
    RoyalBlue3 = "RoyalBlue3"
    RoyalBlue4 = "RoyalBlue4"
    SeaGreen1 = "SeaGreen1"
    SeaGreen2 = "SeaGreen2"
    SeaGreen3 = "SeaGreen3"
    SkyBlue1 = "SkyBlue1"
    SkyBlue2 = "SkyBlue2"
    SkyBlue3 = "SkyBlue3"
    SkyBlue4 = "SkyBlue4"
    SlateBlue1 = "SlateBlue1"
    SlateBlue2 = "SlateBlue2"
    SlateBlue3 = "SlateBlue3"
    SlateBlue4 = "SlateBlue4"
    SlateGray1 = "SlateGray1"
    SlateGray2 = "SlateGray2"
    SlateGray3 = "SlateGray3"
    SlateGray4 = "SlateGray4"
    SpringGreen2 = "SpringGreen2"
    SpringGreen3 = "SpringGreen3"
    SpringGreen4 = "SpringGreen4"
    SteelBlue1 = "SteelBlue1"
    SteelBlue2 = "SteelBlue2"
    SteelBlue3 = "SteelBlue3"
    SteelBlue4 = "SteelBlue4"
    VioletRed1 = "VioletRed1"
    VioletRed2 = "VioletRed2"
    VioletRed3 = "VioletRed3"
    VioletRed4 = "VioletRed4"
    alice_blue = "aliceblue"
    antique_white = "antiquewhite"
    aquamarine = "aquamarine"
    aquamarine2 = "aquamarine2"
    aquamarine4 = "aquamarine4"
    azure = "azure"
    azure2 = "azure2"
    azure3 = "azure3"
    azure4 = "azure4"
    bisque = "bisque"
    bisque2 = "bisque2"
    bisque3 = "bisque3"
    bisque4 = "bisque4"
    blanched_almond = "blanchedalmond"
    blue = "blue"
    blue2 = "blue2"
    blue4 = "blue4"
    blue_violet = "blueviolet"
    brown1 = "brown1"
    brown2 = "brown2"
    brown3 = "brown3"
    brown4 = "brown4"
    burlywood1 = "burlywood1"
    burlywood2 = "burlywood2"
    burlywood3 = "burlywood3"
    burlywood4 = "burlywood4"
    cadet_blue = "cadetblue"
    chartreuse2 = "chartreuse2"
    chartreuse3 = "chartreuse3"
    chartreuse4 = "chartreuse4"
    chocolate1 = "chocolate1"
    chocolate2 = "chocolate2"
    chocolate3 = "chocolate3"
    coral = "coral"
    coral1 = "coral1"
    coral2 = "coral2"
    coral3 = "coral3"
    coral4 = "coral4"
    cornflower_blue = "cornflowerblue"
    cornsilk2 = "cornsilk2"
    cornsilk3 = "cornsilk3"
    cornsilk4 = "cornsilk4"
    cyan = "cyan"
    cyan2 = "cyan2"
    cyan3 = "cyan3"
    cyan4 = "cyan4"
    dark_goldenrod = "darkgoldenrod"
    dark_green = "darkgreen"
    dark_khaki = "darkkhaki"
    dark_olive_green = "darkolivegreen"
    dark_orange = "darkorange"
    dark_orchid = "darkorchid"
    dark_salmon = "darksalmon"
    dark_sea_green = "darkseagreen"
    dark_slate_blue = "darkslateblue"
    dark_slate_gray = "darkslategray"
    dark_turquoise = "darkturquoise"
    dark_violet = "darkviolet"
    deep_pink = "deeppink"
    deep_sky_blue = "deepskyblue"
    dim_gray = "dimgray"
    dodger_blue = "dodgerblue"
    firebrick1 = "firebrick1"
    firebrick2 = "firebrick2"
    firebrick3 = "firebrick3"
    firebrick4 = "firebrick4"
    floral_white = "floralwhite"
    forest_green = "forestgreen"
    gainsboro = "gainsboro"
    ghost_white = "ghostwhite"
    gold = "gold"
    gold2 = "gold2"
    gold3 = "gold3"
    gold4 = "gold4"
    goldenrod = "goldenrod"
    goldenrod1 = "goldenrod1"
    goldenrod2 = "goldenrod2"
    goldenrod3 = "goldenrod3"
    goldenrod4 = "goldenrod4"
    gray = "gray"
    gray0 = "gray0"
    gray100 = "gray100"
    gray20 = "gray20"
    gray40 = "gray40"
    gray60 = "gray60"
    gray80 = "gray80"
    green2 = "green2"
    green3 = "green3"
    green4 = "green4"
    green_yellow = "greenyellow"
    honeydew2 = "honeydew2"
    honeydew3 = "honeydew3"
    honeydew4 = "honeydew4"
    hot_pink = "hotpink"
    indian_red = "indianred"
    ivory2 = "ivory2"
    ivory3 = "ivory3"
    ivory4 = "ivory4"
    khaki = "khaki"
    khaki1 = "khaki1"
    khaki2 = "khaki2"
    khaki3 = "khaki3"
    khaki4 = "khaki4"
    lavender = "lavender"
    lavender_blush = "lavenderblush"
    lawn_green = "lawngreen"
    lemon_chiffon = "lemonchiffon"
    light_blue = "lightblue"
    light_coral = "lightcoral"
    light_cyan = "lightcyan"
    light_goldenrod = "lightgoldenrod"
    light_goldenrod_yellow = "lightgoldenrodyellow"
    light_grey = "lightgrey"
    light_pink = "lightpink"
    light_salmon = "lightsalmon"
    light_sea_green = "lightseagreen"
    light_sky_blue = "lightskyblue"
    light_slate_blue = "lightslateblue"
    light_slate_gray = "lightslategray"
    light_steel_blue = "lightsteelblue"
    light_yellow = "lightyellow"
    lime_green = "limegreen"
    linen = "linen"
    magenta2 = "magenta2"
    magenta3 = "magenta3"
    magenta4 = "magenta4"
    maroon = "maroon"
    maroon1 = "maroon1"
    maroon2 = "maroon2"
    maroon3 = "maroon3"
    maroon4 = "maroon4"
    medium_aquamarine = "mediumaquamarine"
    medium_blue = "mediumblue"
    medium_orchid = "mediumorchid"
    medium_purple = "mediumpurple"
    medium_sea_green = "mediumseagreen"
    medium_slate_blue = "mediumslateblue"
    medium_spring_green = "mediumspringgreen"
    medium_turquoise = "mediumturquoise"
    medium_violet_red = "mediumvioletred"
    midnight_blue = "midnightblue"
    mint_cream = "mintcream"
    misty_rose = "mistyrose"
    navajo_white = "navajowhite"
    navy = "navy"
    old_lace = "oldlace"
    olive_drab = "olivedrab"
    orange = "orange"
    orange2 = "orange2"
    orange3 = "orange3"
    orange4 = "orange4"
    orange_red = "orangered"
    orchid1 = "orchid1"
    orchid2 = "orchid2"
    orchid3 = "orchid3"
    orchid4 = "orchid4"
    pale_goldenrod = "palegoldenrod"
    pale_green = "palegreen"
    pale_turquoise = "paleturquoise"
    pale_violet_red = "palevioletred"
    papaya_whip = "papayawhip"
    peach_puff = "peachpuff"
    pink = "pink"
    pink1 = "pink1"
    pink2 = "pink2"
    pink3 = "pink3"
    pink4 = "pink4"
    plum1 = "plum1"
    plum2 = "plum2"
    plum3 = "plum3"
    plum4 = "plum4"
    powder_blue = "powderblue"
    purple = "purple"
    purple1 = "purple1"
    purple2 = "purple2"
    purple3 = "purple3"
    purple4 = "purple4"
    red = "red"
    red2 = "red2"
    red3 = "red3"
    red4 = "red4"
    rosy_brown = "rosybrown"
    royal_blue = "royalblue"
    saddle_brown = "saddlebrown"
    salmon = "salmon"
    salmon1 = "salmon1"
    salmon2 = "salmon2"
    salmon3 = "salmon3"
    salmon4 = "salmon4"
    sandy_brown = "sandybrown"
    sea_green = "seagreen"
    seashell2 = "seashell2"
    seashell3 = "seashell3"
    seashell4 = "seashell4"
    sienna1 = "sienna1"
    sienna2 = "sienna2"
    sienna3 = "sienna3"
    sienna4 = "sienna4"
    sky_blue = "skyblue"
    slate_blue = "slateblue"
    slate_gray = "slategray"
    snow = "snow"
    snow2 = "snow2"
    snow3 = "snow3"
    snow4 = "snow4"
    spring_green = "springgreen"
    steel_blue = "steelblue"
    tan1 = "tan1"
    tan2 = "tan2"
    tan4 = "tan4"
    thistle = "thistle"
    thistle1 = "thistle1"
    thistle2 = "thistle2"
    thistle3 = "thistle3"
    thistle4 = "thistle4"
    tomato = "tomato"
    tomato2 = "tomato2"
    tomato3 = "tomato3"
    tomato4 = "tomato4"
    turquoise = "turquoise"
    turquoise1 = "turquoise1"
    turquoise2 = "turquoise2"
    turquoise3 = "turquoise3"
    turquoise4 = "turquoise4"
    violet_red = "violetred"
    wheat1 = "wheat1"
    wheat2 = "wheat2"
    wheat3 = "wheat3"
    wheat4 = "wheat4"
    white_smoke = "whitesmoke"
    yellow = "yellow"
    yellow2 = "yellow2"
    yellow3 = "yellow3"
    yellow4 = "yellow4"
    yellow_green = "yellowgreen"
